powered by
Shorthand notation for the quote function. The quote operator simply returns its argument unevaluated and can be applied to any R expression.
quote
.(expr)
any syntactically valid R expression.
The quoted (unevaluated) expression.
Useful for calling model functions with quoted parameter values defined in terms of one or more of the following variables.
nobs
number of observations in data to be fit.
nvars
number of predictor variables.
y
the response variable.
# NOT RUN { ## Stepwise variable selection with BIC glm_fit <- fit(sale_amount ~ ., ICHomes, GLMStepAICModel(k = .(log(nobs)))) varimp(glm_fit) # }
Run the code above in your browser using DataLab