Learn R Programming

MachineShop (version 3.1.0)

set_monitor: Resampling Monitoring Control

Description

Set parameters that control the monitoring of resample estimation of model performance.

Usage

set_monitor(x, progress = TRUE, verbose = FALSE)

Arguments

x

control object.

progress

logical indicating whether to display a progress bar during resampling if a computing cluster is not registered or is registered with the doSNOW package.

verbose

logical indicating whether to enable verbose messages which may be useful for trouble shooting.

Value

Argument x updated with the supplied parameters.

See Also

set_predict, set_strata, resample, SelectedInput, SelectedModel, TunedInput, TunedModel

Examples

Run this code
# NOT RUN {
CVControl() %>% set_monitor(verbose = TRUE)

# }

Run the code above in your browser using DataLab